==> BicARE_1.10.0.zip: BicARE/doc/BicARE.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "BicARE.Rnw"
require(BicARE)


###################################################
### chunk number 2: 
###################################################
#line 48 "BicARE.Rnw"
data(sample.bicData)
sample.bicData


###################################################
### chunk number 3: 
###################################################
#line 56 "BicARE.Rnw"
residue(sample.bicData)  


###################################################
### chunk number 4: 
###################################################
#line 65 "BicARE.Rnw"
set.seed(1)
res.biclustering <- FLOC(sample.bicData, k=15, pGene=0.3, pSample=0.6, r=0.01, 10, 8, 200)


###################################################
### chunk number 5: 
###################################################
#line 69 "BicARE.Rnw"
res.biclustering


###################################################
### chunk number 6: 
###################################################
#line 80 "BicARE.Rnw"
init.genes <- matrix(data=0, nrow=352, ncol=5)
init.samples <- matrix(data=0, nrow=26, ncol=5)
init.genes[1:10,1] <- 1
init.genes[20:30,2] <- 1
init.genes[50:60,3] <- 1
init.samples[1:5,3] <- 1
init.samples[1:5,4] <- 1
init.samples[10:15,5] <- 1


###################################################
### chunk number 7: 
###################################################
#line 101 "BicARE.Rnw"
bic <- bicluster(res.biclustering, 6, graph=FALSE)
plot(bic)


###################################################
### chunk number 8: 
###################################################
#line 112 "BicARE.Rnw"
gsc <- GeneSetCollection(res.biclustering$ExpressionSet[1:50], setType=GOCollection())
res.bic2 <- testSet(res.biclustering, gsc)


###################################################
### chunk number 9: 
###################################################
#line 123 "BicARE.Rnw"
pData(sample.bicData)


###################################################
### chunk number 10: 
###################################################
#line 127 "BicARE.Rnw"
res.bic2 <- testAnnot(res.biclustering, annot=pData(sample.bicData), covariates=c("sex", "type"))

==> BicARE_1.20.0.zip: BicARE/doc/BicARE.R <==
### R code from vignette source 'BicARE.Rnw'

###################################################
### code chunk number 1: BicARE.Rnw:41-42
###################################################
require(BicARE)


###################################################
### code chunk number 2: BicARE.Rnw:47-49
###################################################
data(sample.bicData)
sample.bicData


###################################################
### code chunk number 3: BicARE.Rnw:55-56
###################################################
residue(sample.bicData)  


###################################################
### code chunk number 4: BicARE.Rnw:64-66
###################################################
set.seed(1)
res.biclustering <- FLOC(sample.bicData, k=15, pGene=0.3, pSample=0.6, r=0.01, 10, 8, 200)


###################################################
### code chunk number 5: BicARE.Rnw:68-69
###################################################
res.biclustering


###################################################
### code chunk number 6: BicARE.Rnw:79-87
###################################################
init.genes <- matrix(data=0, nrow=352, ncol=5)
init.samples <- matrix(data=0, nrow=26, ncol=5)
init.genes[1:10,1] <- 1
init.genes[20:30,2] <- 1
init.genes[50:60,3] <- 1
init.samples[1:5,3] <- 1
init.samples[1:5,4] <- 1
init.samples[10:15,5] <- 1


###################################################
### code chunk number 7: BicARE.Rnw:100-102
###################################################
bic <- bicluster(res.biclustering, 6, graph=FALSE)
plot(bic)


###################################################
### code chunk number 8: BicARE.Rnw:111-113
###################################################
gsc <- GeneSetCollection(res.biclustering$ExpressionSet[1:50], setType=GOCollection())
res.bic2 <- testSet(res.biclustering, gsc)


###################################################
### code chunk number 9: BicARE.Rnw:122-123
###################################################
pData(sample.bicData)


###################################################
### code chunk number 10: BicARE.Rnw:126-127
###################################################
res.bic2 <- testAnnot(res.biclustering, annot=pData(sample.bicData), covariates=c("sex", "type"))
